import java.util.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.awt.geom.*;

class CompositingFrame extends JFrame {

    private DrawPanel drawPanel = new DrawPanel();
    private JComboBox options;

    
    class DrawPanel extends JPanel {
   
      public DrawPanel() {
        setBackground(Color.lightGray);
      }
      
      public Dimension getPreferredSize() {
        return new Dimension(200, 150);
      }
    
      public void paintComponent(Graphics g) {
        // Create off-screen image
        Image img = createImage(200, 150);
        Graphics2D ig2 = (Graphics2D)img.getGraphics();   
        // Paint first element (red ellipse)   
        ig2.setPaint(Color.red);
        ig2.fill(new Ellipse2D.Double(20, 50, 150, 50));
        // Obtain compositing rule from user
        String rule = (String)options.getSelectedItem();
        if (rule.equals("Src")) ig2.setComposite(AlphaComposite.Src);
        if (rule.equals("Dst")) ig2.setComposite(AlphaComposite.Dst);
        if (rule.equals("Src-Over-Dst")) ig2.setComposite(AlphaComposite.SrcOver);
        if (rule.equals("Dst-Over-Src")) ig2.setComposite(AlphaComposite.DstOver);
        if (rule.equals("Src-In-Dst")) ig2.setComposite(AlphaComposite.SrcIn);
        if (rule.equals("Dst-In-Src")) ig2.setComposite(AlphaComposite.DstIn);
        if (rule.equals("Src-Out-Dst")) ig2.setComposite(AlphaComposite.SrcOut);
        if (rule.equals("Dst-Out-Src")) ig2.setComposite(AlphaComposite.DstOut);
        if (rule.equals("Src-Atop-Dst")) ig2.setComposite(AlphaComposite.SrcAtop);
        if (rule.equals("Dst-Atop-Src")) ig2.setComposite(AlphaComposite.DstAtop);
        if (rule.equals("Clear")) ig2.setComposite(AlphaComposite.Clear);
        if (rule.equals("Xor")) ig2.setComposite(AlphaComposite.Xor);
        // Paint second element (blue rectangle)
        ig2.setPaint(Color.blue);
        ig2.fill(new Rectangle2D.Double(75, 20, 50, 110));
        // Display on screen
        super.paintComponent(g);
        Graphics2D g2 = (Graphics2D) g;
        g2.drawImage(img, 0, 0, null);
      }
    }

	public CompositingFrame() {
	 	setTitle("Compositing");
	 	getContentPane().add(drawPanel,BorderLayout.NORTH);
	 	JPanel controlPanel = new JPanel();
	 	getContentPane().add(controlPanel,BorderLayout.SOUTH);
	 	
        options = new JComboBox(
          new String[] {"Src", "Dst", "Src-Over-Dst", "Dst-Over-Src", "Src-In-Dst", "Dst-In-Src", "Src-Out-Dst", 
            "Dst-Out-Src", "Src-Atop-Dst", "Dst-Atop-Src", "Clear", "Xor"});
        options.addItemListener(new ItemListener() {
          public void itemStateChanged(ItemEvent ie) {
            repaint();
          }
        });
        controlPanel.add(options);
	 	
        JButton exitButton = new JButton("Exit");
	 	exitButton.addActionListener(new ActionListener(){
	 	  public void actionPerformed (ActionEvent event) {
            System.exit(0);
          }
	 	});
	 	controlPanel.add(exitButton);
	 	
	 	addWindowListener(new WindowAdapter(){
	 	  public void windowClosing(WindowEvent we) {
            System.exit(0);
          }
         });
	 	
	 	pack();
	 	setVisible(true);
	 }
	 
}

class Compositing {

  public static void main (String[] argv) {	
    CompositingFrame cf = new CompositingFrame();
  }
}
