import java.util.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.awt.geom.*;

class CompositingAlphaFrame extends JFrame {

    private DrawPanel drawPanel = new DrawPanel();
    private JComboBox options;

    
    class DrawPanel extends JPanel {
   
      public DrawPanel() {
        setBackground(Color.lightGray);
      }
      
      public Dimension getPreferredSize() {
        return new Dimension(200, 150);
      }
    
      public void paintComponent(Graphics g) {
        // Create off-screen image
        Image img = createImage(200, 150);
        Graphics2D ig2 = (Graphics2D)img.getGraphics();   
        // Paint first element (red ellipse)   
        ig2.setPaint(Color.red);
        ig2.fill(new Ellipse2D.Double(20, 50, 150, 50));
        // Obtain compositing rule from user
        String rule = (String)options.getSelectedItem();
        int ruleCode = AlphaComposite.SRC_OVER;
        if (rule.equals("Src")) ruleCode = AlphaComposite.SRC;
        if (rule.equals("Dst")) ruleCode = AlphaComposite.DST;
        if (rule.equals("Src-Over-Dst")) ruleCode = AlphaComposite.SRC_OVER;
        if (rule.equals("Dst-Over-Src")) ruleCode = AlphaComposite.DST_OVER;
        if (rule.equals("Src-In-Dst")) ruleCode = AlphaComposite.SRC_IN;
        if (rule.equals("Dst-In-Src")) ruleCode = AlphaComposite.DST_IN;
        if (rule.equals("Src-Out-Dst")) ruleCode = AlphaComposite.SRC_OUT;
        if (rule.equals("Dst-Out-Src")) ruleCode = AlphaComposite.DST_OUT;
        if (rule.equals("Src-Atop-Dst")) ruleCode = AlphaComposite.SRC_ATOP;
        if (rule.equals("Dst-Atop-Src")) ruleCode = AlphaComposite.DST_ATOP;
        if (rule.equals("Clear")) ruleCode = AlphaComposite.CLEAR;
        if (rule.equals("Xor")) ruleCode = AlphaComposite.XOR;
        // Paint second element (blue rectangle)
        ig2.setComposite(AlphaComposite.getInstance(ruleCode, 0.4f));
        ig2.setPaint(Color.blue);
        ig2.fill(new Rectangle2D.Double(75, 20, 50, 110));
        // Display on screen
        super.paintComponent(g);
        Graphics2D g2 = (Graphics2D) g;
        g2.drawImage(img, 0, 0, null);
      }
    }

	public CompositingAlphaFrame() {
	 	setTitle("AlphaCompositing");
	 	getContentPane().add(drawPanel,BorderLayout.NORTH);
	 	JPanel controlPanel = new JPanel();
	 	getContentPane().add(controlPanel,BorderLayout.SOUTH);
	 	
        options = new JComboBox(
          new String[] {"Src", "Dst", "Src-Over-Dst", "Dst-Over-Src", "Src-In-Dst", "Dst-In-Src", "Src-Out-Dst", 
            "Dst-Out-Src", "Src-Atop-Dst", "Dst-Atop-Src", "Clear", "Xor"});
        options.addItemListener(new ItemListener() {
          public void itemStateChanged(ItemEvent ie) {
            repaint();
          }
        });
        controlPanel.add(options);
	 	
        JButton exitButton = new JButton("Exit");
	 	exitButton.addActionListener(new ActionListener(){
	 	  public void actionPerformed (ActionEvent event) {
            System.exit(0);
          }
	 	});
	 	controlPanel.add(exitButton);
	 	
	 	addWindowListener(new WindowAdapter(){
	 	  public void windowClosing(WindowEvent we) {
            System.exit(0);
          }
         });
	 	
	 	pack();
	 	setVisible(true);
	 }
	 
}

class CompositingAlpha {

  public static void main (String[] argv) {	
    CompositingAlphaFrame cf = new CompositingAlphaFrame();
  }
}
